
form[data-role=poll] ul {
    padding: 0;
    margin: 0;
}

form[data-role=poll] ul li {
    list-style: none;
}

form[data-role=poll] ul li input[type=radio] {
    width: 22px;
    height: 22px;
    position: relative;
    top: 4px;
}

form[data-role=poll] .panel-heading {
    display: inline-block;
    width: 100%;
}

form[data-role=poll] ul li label {
    vertical-align: middle;
}

form[data-role=poll] h3.heading-xs {
    margin-bottom: 5px;
    font-weight: bold;
}
