# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-02-23 13:56
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('poll', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='poll',
            options={'get_latest_by': 'id', 'ordering': ['-id'], 'verbose_name': 'Poll', 'verbose_name_plural': 'Polls'},
        ),
        migrations.AlterModelOptions(
            name='pollchoice',
            options={'ordering': ('order',), 'verbose_name': 'Poll choice', 'verbose_name_plural': 'Poll choices'},
        ),
        migrations.AddField(
            model_name='pollchoice',
            name='order',
            field=models.PositiveIntegerField(db_index=True, default=1, editable=False),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='poll',
            name='created',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created'),
        ),
        migrations.AlterField(
            model_name='poll',
            name='votes',
            field=models.IntegerField(default=0, editable=False, verbose_name='Votes'),
        ),
        migrations.AlterField(
            model_name='pollchoice',
            name='poll',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='choices', to='poll.Poll', verbose_name='Poll'),
        ),
        migrations.AlterField(
            model_name='pollchoice',
            name='value',
            field=models.CharField(max_length=255, verbose_name='Value'),
        ),
        migrations.AlterField(
            model_name='pollchoice',
            name='votes',
            field=models.IntegerField(default=0, editable=False, verbose_name='Votes'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='choice',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='poll.PollChoice', verbose_name='Choice'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='created',
            field=models.DateTimeField(auto_now_add=True, db_index=True, verbose_name='Created'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='ip',
            field=models.CharField(db_index=True, editable=False, max_length=40, verbose_name='IP'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='poll',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='poll.Poll', verbose_name='Poll'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='session',
            field=models.CharField(db_index=True, editable=False, max_length=40, verbose_name='Session'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='user',
            field=models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='vote',
            name='user_agent',
            field=models.CharField(editable=False, max_length=255, verbose_name='User agent'),
        ),
    ]
