
{% load i18n %}


{% if poll %}
    <form data-role="poll" data-poll-id="{{ poll.pk }}"
          action="{% url 'poll:vote' %}?referrer={{ request.get_full_path }}">

        <div class="tab-content">
            {% if not is_poll_voted %}
                <div role="tabpanel" class="tab-pane active" id="poll-form">
                    {% include 'poll/form.html' %}
                </div>
            {% endif %}
            <div role="tabpanel" class="tab-pane {% if is_poll_voted %}active{% endif %}" id="poll-result">
                {% include 'poll/result.html' %}
            </div>
        </div>
    </form>
{% endif %}
