
{% load i18n %}


<div class="panel panel-default-dark">
    <div class="panel-heading">
        <h3 class="panel-title">
            {{ poll.question }}
        </h3>
    </div>
    <div class="panel-body">
        {% csrf_token %}
        {{ form.poll }}
        {{ form.choice }}
    </div>
    <div class="panel-footer">
        <button type="submit" class="btn btn-success" data-role="vote-btn">
            <i class="fa fa-check"></i>
            {% trans 'Vote' %}
        </button>

        <a href="#poll-result" aria-controls="poll-form" role="tab" data-toggle="tab"
           class="btn btn-primary pull-right">
            <i class="fa fa-bar-chart"></i>
            {% trans 'Result' %}
        </a>
    </div>
</div>